@@ -22,7 +22,7 @@ API_ROUTE_NAME_PREFIX = "cube_api_v1_"
 # Default parameters to use for API routes.
 DEFAULT_ROUTE_PARAMS = {
     "request_method": "POST",
-    "renderer": "json",
+    "renderer": "cubicweb_api_json",
     "require_csrf": False,
     "openapi": True,
 }
