@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 from enum import Enum
+from typing import Callable
 
 from cubicweb import AuthenticationError, QueryError, Unauthorized, Forbidden
 from cubicweb.schema_exporters import JSONSchemaExporter
@@ -33,14 +34,18 @@ from cubicweb_api.constants import (
     API_ROUTE_NAME_PREFIX,
 )
 from cubicweb_api.httperrors import get_http_error, get_http_500_error
-from cubicweb_api.jwt_auth import setup_jwt
-from cubicweb_api.openapi.openapi import register_openapi_routes
-from cubicweb_api.util import get_cw_repo, get_cw_request, get_api_path_prefix
+from cubicweb_api.auth.jwt_auth import setup_jwt
+from cubicweb_api.openapi.openapi import setup_openapi
+from cubicweb_api.util import get_cw_repo, get_cw_request, get_transactions_repository
 
 log = logging.getLogger(__name__)
 
 
 class ApiRoutes(str, Enum):
+    """
+    All the available routes as listed in the openapi/openapi_template.yml file.
+    """
+
     schema = "schema"
     rql = "rql"
     login = "login"
@@ -52,52 +57,83 @@ class ApiRoutes(str, Enum):
 
 
 def is_user_allowed(request: Request):
+    """
+    Checks if the user making the request is authenticated or if anonymous access is enabled
+
+    :param request: The request initiated by the user
+    :return: True if the user can access the resource, false otherwise
+    """
     return (
         request.authenticated_userid is not None
         or get_cw_repo(request).config["anonymous-user"] is not None
     )
 
 
-def cw_view_config(route_name: str, **kwargs):
-    return view_config(
-        route_name=f"{API_ROUTE_NAME_PREFIX}{route_name}",
-        **dict(DEFAULT_ROUTE_PARAMS, **kwargs),
-    )
-
-
-def view_exception_handler(func):
+def get_route_name(route_name: str) -> str:
     """
-    Use it as a decorator for any pyramid view to catch AuthenticationError to raise HTTP 401
-    and any other leftover exceptions to raise HTTP 500.
+    Generates a unique route name using the api prefix to prevent clashes with routes
+    from other cubes.
+
+    :param route_name: The route name base
+    :return: The generated route name
+    """
+    return f"{API_ROUTE_NAME_PREFIX}{route_name}"
+
+
+def catch_rql_errors(func: Callable):
+    """
+    Calls and returns the result of the given function.
+    If an error related to RQL occurs, this will raise an HTTP 400 error
+
+    :param func: The function to check for errors
+    :return: The function's result if no error occurred
+    :raise HTTPError: with 400 code if a RQL related exception is caught
+    """
+    try:
+        return func()
+    except (RQLException, QueryError, ValidationError, UnknownType) as e:
+        log.info(e.__class__.__name__, exc_info=True)
+        raise get_http_error(400, e.__class__.__name__, str(e))
+
+
+def view_exception_handler(func: Callable):
+    """
+    Use it as a decorator for any pyramid view to catch authentication errors
+    and raise HTTP 401 or 403 errors.
+    It also catches any other leftover exceptions and raises an HTTP 500 error.
 
     :param func: The pyramid view function
-    :return:
+    :raise HTTPError: with different error codes depending on the exception caught
     """
 
     def request_wrapper(request: Request):
         try:
             return func(request)
         except HTTPError as e:
+            # The decorated function raised its own HTTP error, simply forward it.
             return e
         except (AuthenticationError, Unauthorized) as e:
+            # User was not authenticated, return 401 HTTP error
             log.info(e.__class__.__name__, exc_info=True)
             return get_http_error(401, e.__class__.__name__, str(e))
         except Forbidden as e:
+            # User was authenticated but had insufficient privileges, return 403 HTTP error
             log.info(e.__class__.__name__, exc_info=True)
             return get_http_error(403, e.__class__.__name__, str(e))
         except Exception:
+            # An exception was raised but not caught, this is a server error (HTTP 5OO)
             log.info("ServerError", exc_info=True)
             raise get_http_500_error()
 
     return request_wrapper
 
 
-def authorized_users_only(func):
+def authorized_users_only(func: Callable):
     """
-    Raise an AuthenticationError if no user is detected and anonymous access is disabled.
+    Use it as a decorator to raise an AuthenticationError if no user is detected
+    and anonymous access is disabled.
 
-    :param func:  The pyramid view function
-    :return:
+    :param func: The pyramid view function
     """
 
     def request_wrapper(request: Request):
@@ -108,12 +144,15 @@ def authorized_users_only(func):
     return request_wrapper
 
 
-@cw_view_config(route_name=ApiRoutes.schema, request_method="GET")
+@view_config(
+    route_name=get_route_name(ApiRoutes.schema),
+    **dict(DEFAULT_ROUTE_PARAMS, request_method="GET"),
+)
 @view_exception_handler
 @authorized_users_only
 def schema_route(request: Request):
     """
-    Returns this instance's Schema
+    See the openapi/openapi_template.yml file for more information on this route.
     """
     repo = get_cw_repo(request)
     exporter = JSONSchemaExporter()
@@ -121,30 +160,30 @@ def schema_route(request: Request):
     return exported_schema
 
 
-@cw_view_config(route_name=ApiRoutes.rql)
+@view_config(
+    route_name=get_route_name(ApiRoutes.rql),
+    **DEFAULT_ROUTE_PARAMS,
+)
 @view_exception_handler
 @authorized_users_only
 def rql_route(request: Request):
     """
-    Executes the given rql query
+    See the openapi/openapi_template.yml file for more information on this route.
     """
     request_params = request.openapi_validated.body
     query: str = request_params["query"]
     params: dict = request_params["params"]
-    try:
-        result = get_cw_request(request).execute(query, params)
-    except (RQLException, QueryError, ValidationError, UnknownType) as e:
-        log.info(e.__class__.__name__, exc_info=True)
-        raise get_http_error(400, e.__class__.__name__, str(e))
-    else:
-        return result.rows
+    return catch_rql_errors(lambda: get_cw_request(request).execute(query, params).rows)
 
 
-@cw_view_config(route_name=ApiRoutes.login)
+@view_config(
+    route_name=get_route_name(ApiRoutes.login),
+    **DEFAULT_ROUTE_PARAMS,
+)
 @view_exception_handler
 def login_route(request: Request):
     """
-    Tries to log in the user
+    See the openapi/openapi_template.yml file for more information on this route.
     """
     request_params = request.openapi_validated.body
     login: str = request_params["login"]
@@ -169,67 +208,66 @@ def login_route(request: Request):
             return Response(headers=headers, status=204)
 
 
-@cw_view_config(route_name=ApiRoutes.transaction_begin)
+@view_config(
+    route_name=get_route_name(ApiRoutes.transaction_begin),
+    **DEFAULT_ROUTE_PARAMS,
+)
 @view_exception_handler
 @authorized_users_only
 def transaction_begin_route(request: Request):
     """
-    Starts a new transaction
+    See the openapi/openapi_template.yml file for more information on this route.
     """
-    transactions = get_cw_repo(request).api_transactions
+    transactions = get_transactions_repository(request)
     user = get_cw_request(request).user
     return transactions.begin_transaction(user)
 
 
-@cw_view_config(route_name=ApiRoutes.transaction_execute)
+@view_config(
+    route_name=get_route_name(ApiRoutes.transaction_execute),
+    **DEFAULT_ROUTE_PARAMS,
+)
 @view_exception_handler
 @authorized_users_only
 def transaction_execute_route(request: Request):
     """
-    Executes the given rql query as part of a transaction
+    See the openapi/openapi_template.yml file for more information on this route.
     """
-    transactions = get_cw_repo(request).api_transactions
+    transactions = get_transactions_repository(request)
     request_params = request.openapi_validated.body
     uuid: str = request_params["uuid"]
     query: str = request_params["query"]
     params: dict = request_params["params"]
-    try:
-        result = transactions[uuid].execute(query, params)
-    except (RQLException, QueryError, ValidationError, UnknownType) as e:
-        log.info(e.__class__.__name__, exc_info=True)
-        raise get_http_error(400, e.__class__.__name__, str(e))
-    else:
-        return result.rows
+    return catch_rql_errors(lambda: transactions[uuid].execute(query, params).rows)
 
 
-@cw_view_config(route_name=ApiRoutes.transaction_commit)
+@view_config(
+    route_name=get_route_name(ApiRoutes.transaction_commit),
+    **DEFAULT_ROUTE_PARAMS,
+)
 @view_exception_handler
 @authorized_users_only
 def transaction_commit_route(request: Request):
     """
-    Commits a transaction
+    See the openapi/openapi_template.yml file for more information on this route.
     """
-    transactions = get_cw_repo(request).api_transactions
+    transactions = get_transactions_repository(request)
     request_params = request.openapi_validated.body
     uuid: str = request_params["uuid"]
-    try:
-        commit_result = transactions[uuid].commit()
-    except (RQLException, QueryError, ValidationError, UnknownType) as e:
-        log.info(e.__class__.__name__, exc_info=True)
-        raise get_http_error(400, e.__class__.__name__, str(e))
-    else:
-        transactions[uuid].rollback()
-        return commit_result
+    return catch_rql_errors(lambda: transactions[uuid].commit())
 
 
-@cw_view_config(route_name=ApiRoutes.transaction_rollback)
+@view_config(
+    route_name=get_route_name(ApiRoutes.transaction_rollback),
+    **DEFAULT_ROUTE_PARAMS,
+)
 @view_exception_handler
 @authorized_users_only
 def transaction_rollback_route(request: Request):
     """
-    Rollback a transaction
+    See the openapi/openapi_template.yml file for more information on this route.
     """
-    transactions = get_cw_repo(request).api_transactions
+    transactions = get_transactions_repository(request)
     request_params = request.openapi_validated.body
     uuid: str = request_params["uuid"]
     rollback_result = transactions[uuid].rollback()
@@ -241,7 +279,6 @@ def includeme(config: Configurator):
     setup_jwt(config)
     repo = get_cw_repo(config)
     repo.api_transactions = ApiTransactionsRepository(repo)
-    route_prefix = get_api_path_prefix(config)
-    register_openapi_routes(config, route_prefix)
+    setup_openapi(config)
     config.pyramid_openapi3_register_routes()
     config.scan()
