@@ -78,10 +78,8 @@ def get_api_server_base(config: Configurator) -> str:
     :raise ConfigurationError if the name set in config is not valid
     """
     repo = get_cw_repo(config)
-    server_name: str = (
-        repo.get_option_value("api-server-name")
-        or get_cw_all_in_one_config(config).default_base_url()
-    )
+    with repo.internal_cnx() as cnx:
+        server_name: str = repo.get_option_value("api-server-name") or cnx.base_url()
     match = re.match("^[a-zA-Z0-9-_@.&+!*(),/:]{1,60}$", server_name)
     if match:
         return server_name
@@ -89,7 +87,7 @@ def get_api_server_base(config: Configurator) -> str:
         if len(server_name) > 60:
             raise ConfigurationError(
                 f"api-server-name '{server_name}' is too long. "
-                f"Max size allowed is 60 characters. "
+                "Max size allowed is 60 characters. "
                 f"Current size is {len(server_name)}."
             )
         raise ConfigurationError(
@@ -118,7 +116,7 @@ def get_api_path_prefix(config: Configurator) -> str:
         if len(path_prefix) > 30:
             raise ConfigurationError(
                 f"api-path-prefix '{path_prefix}' is too long. "
-                f"Max size allowed is 30 characters. "
+                "Max size allowed is 30 characters. "
                 f"Current size is {len(path_prefix)}."
             )
         if not path_prefix.startswith("/"):
